GRANT_TYPE_PASSWORD = 'password'
GRANT_TYPE_REFRESH = 'refresh_token'

# url routes
TOKEN_URL = '/oauth/token'  # only route that leads with '/' (does not use Vault.base_url)
DOCUMENTS_URL = 'documents'
REVISIONS_URL = 'revisions'
INDEX_FIELDS_URL = 'indexfields'
EMAILS_URL = 'emails'
FILES_URL = 'files'
FOLDERS_URL = 'folders'
SELECT_OPTIONS_URL = 'selectoptions'
WORKFLOW_ASSIGNMENTS_URL = 'workflowassignments'
FORM_TEMPLATES_URL = 'formtemplates'
FORMS_URL = 'forms'
PDF_URL = 'PDF'
FIELDS_URL = 'fields'
FORM_INSTANCE_URL = 'forminstance'
RELATE_FORM_URL = 'relateform?relatetoid='
RELATE_DOCUMENT_URL = 'relatedocument?relatetoid='
RELATE_PROJECT_URL = 'relateproject?relatetoid='
UNRELATE_FORM_URL = 'unrelateform?relatetoid='
UNRELATE_DOCUMENT_URL = 'unrelatedocument?relatetoid='
UNRELATE_PROJECT_URL = 'unrelateproject?relatetoid='
VV_LOGIN_URL = 'vvlogin?token='
RETURN_URL = '&returnUrl=~%2fFormDetails%3fformid%3d'
HIDE_MENU_URL = '%26hidemenu%3Dtrue'
GROUPS_URL = 'groups'
USERS_URL = 'users'
SITES_URL = 'sites'
WEB_TOKEN_URL = 'webtoken'
SITE_ID_URL = '?siteId='
TOKEN_EXPIRY_TIMEZONE = 'UTC'
JWT_URL = 'getJWT'
STATUS_URL = 'status'
